@@ -32,6 +32,7 @@ __all__ = [
     "get_has_canonical",
     "get_has_parts",
     "get_homepage",
+    "get_jskos_download",
     "get_json_download",
     "get_keywords",
     "get_logo",
@@ -57,6 +58,7 @@ __all__ = [
     "get_repository",
     "get_repository_to_prefix",
     "get_resource",
+    "get_skos_download",
     "get_synonyms",
     "get_version",
     "get_versions",
@@ -83,11 +85,12 @@ def get_resource(prefix: str, *, strict: Literal[False] = False) -> Resource | N
 def get_resource(prefix: str, *, strict: bool = False) -> Resource | None:
     """Get the Bioregistry entry for the given prefix.
 
-    :param prefix: The prefix to look up, which is normalized with :func:`normalize_prefix`
-        before lookup in the Bioregistry
+    :param prefix: The prefix to look up, which is normalized with
+        :func:`normalize_prefix` before lookup in the Bioregistry
     :param strict: If true, requires the prefix to be valid or raise an exveption
-    :returns: The Bioregistry entry dictionary, which includes several keys cross-referencing
-        other registries when available.
+
+    :returns: The Bioregistry entry dictionary, which includes several keys
+        cross-referencing other registries when available.
     """
     if strict:
         return manager.get_resource(prefix, strict=True)
@@ -140,8 +143,9 @@ def get_description(prefix: str, *, use_markdown: bool = False) -> str | None:
     """Get the description for the given prefix, if available.
 
     :param prefix: The prefix to lookup.
-    :param use_markdown: Should :mod:`markupsafe` and :mod:`markdown` wrap the description
-        string
+    :param use_markdown: Should :mod:`markupsafe` and :mod:`markdown` wrap the
+        description string
+
     :returns: The description, if available.
     """
     return manager.get_description(prefix, use_markdown=use_markdown)
@@ -151,6 +155,7 @@ def get_preferred_prefix(prefix: str) -> str | None:
     """Get the preferred prefix (e.g., with stylization) if it exists.
 
     :param prefix: The prefix to lookup.
+
     :returns: The preferred prefix, if annotated in the Bioregistry or OBO Foundry.
 
     No preferred prefix annotation, defaults to normalized prefix
@@ -168,8 +173,8 @@ def get_preferred_prefix(prefix: str) -> str | None:
     >>> get_preferred_prefix("fbbt")
     'FBbt'
 
-    Preferred prefix from the OBO Foundry overridden by the Bioregistry
-    (see also https://github.com/OBOFoundry/OBOFoundry.github.io/issues/1559)
+    Preferred prefix from the OBO Foundry overridden by the Bioregistry (see also
+    https://github.com/OBOFoundry/OBOFoundry.github.io/issues/1559)
 
     >>> get_preferred_prefix("dpo")
     'DPO'
@@ -203,9 +208,12 @@ def get_keywords(prefix: str) -> list[str] | None:
 def get_pattern(prefix: str) -> str | None:
     """Get the pattern for the given prefix, if it's available.
 
-    :param prefix: The prefix to look up, which is normalized with :func:`normalize_prefix`
-        before lookup in the Bioregistry
-    :returns: The pattern for the prefix, if it is available, using the following order of preference:
+    :param prefix: The prefix to look up, which is normalized with
+        :func:`normalize_prefix` before lookup in the Bioregistry
+
+    :returns: The pattern for the prefix, if it is available, using the following order
+        of preference:
+
         1. Custom
         2. MIRIAM
         3. Wikidata
@@ -228,10 +236,11 @@ def get_appears_in(prefix: str) -> list[str] | None:
     This is complementary to :func:`get_depends_on`.
 
     :param prefix: The prefix to look up
+
     :returns: The list of resources this prefix has been annotated to appear in. This
-        list could be incomplete, since curation of these fields can easily get out
-        of sync with curation of the resource itself. However, false positives should
-        be pretty rare.
+        list could be incomplete, since curation of these fields can easily get out of
+        sync with curation of the resource itself. However, false positives should be
+        pretty rare.
 
     >>> import bioregistry
     >>> assert "bfo" not in bioregistry.get_appears_in("foodon")
@@ -246,10 +255,11 @@ def get_depends_on(prefix: str) -> list[str] | None:
     This is complementary to :func:`get_appears_in`.
 
     :param prefix: The prefix to look up
+
     :returns: The list of resources this prefix has been annotated to depend on. This
-        list could be incomplete, since curation of these fields can easily get out
-        of sync with curation of the resource itself. However, false positives should
-        be pretty rare.
+        list could be incomplete, since curation of these fields can easily get out of
+        sync with curation of the resource itself. However, false positives should be
+        pretty rare.
 
     >>> import bioregistry
     >>> assert "bfo" in bioregistry.get_depends_on("foodon")
@@ -261,16 +271,16 @@ def get_depends_on(prefix: str) -> list[str] | None:
 def get_has_canonical(prefix: str) -> str | None:
     """Get the canonical prefix.
 
-    If two (or more) stand-alone resources both provide for the same
-    semantic space, but none of them have a first-party claim to the
-    semantic space, then the ``has_canonical`` relationship is used
-    to choose a preferred prefix. This is different than the
-    ``provides``, relationship, which is appropriate when it's obvious
-    that one resource has a full claim to the semantic space.
+    If two (or more) stand-alone resources both provide for the same semantic space, but
+    none of them have a first-party claim to the semantic space, then the
+    ``has_canonical`` relationship is used to choose a preferred prefix. This is
+    different than the ``provides``, relationship, which is appropriate when it's
+    obvious that one resource has a full claim to the semantic space.
 
     :param prefix: The prefix to lookup.
-    :returns: The canonical prefix for this one, if one is annotated.
-        This is the inverse of :func:`get_canonical_for`.
+
+    :returns: The canonical prefix for this one, if one is annotated. This is the
+        inverse of :func:`get_canonical_for`.
 
     >>> get_has_canonical("refseq")
     'ncbiprotein'
@@ -284,8 +294,9 @@ def get_canonical_for(prefix: str) -> list[str] | None:
     """Get the prefixes for which this is annotated as canonical.
 
     :param prefix: The prefix to lookup.
-    :returns: The prefixes for which this is annotated as canonical.
-        This is the inverse of :func:`get_has_canonical`.
+
+    :returns: The prefixes for which this is annotated as canonical. This is the inverse
+        of :func:`get_has_canonical`.
 
     >>> "refseq" in get_canonical_for("ncbiprotein")
     True
@@ -299,14 +310,16 @@ def get_identifiers_org_prefix(prefix: str) -> str | None:
     """Get the identifiers.org prefix if available.
 
     :param prefix: The prefix to lookup.
-    :returns: The Identifiers.org/MIRIAM prefix corresponding to the prefix, if mappable.
+
+    :returns: The Identifiers.org/MIRIAM prefix corresponding to the prefix, if
+        mappable.
 
     >>> import bioregistry
     >>> bioregistry.get_identifiers_org_prefix("chebi")
     'chebi'
     >>> bioregistry.get_identifiers_org_prefix("ncbitaxon")
     'taxonomy'
-    >>> assert bioregistry.get_identifiers_org_prefix("MONDO") is None
+    >>> assert bioregistry.get_identifiers_org_prefix("bioregistry") is None
     """
     entry = manager.get_resource(prefix)
     if entry is None:
@@ -318,6 +331,7 @@ def get_n2t_prefix(prefix: str) -> str | None:
     """Get the name-to-thing prefix if available.
 
     :param prefix: The prefix to lookup.
+
     :returns: The Name-to-Thing prefix corresponding to the prefix, if mappable.
 
     >>> import bioregistry
@@ -334,7 +348,9 @@ def get_wikidata_prefix(prefix: str) -> str | None:
     """Get the wikidata prefix if available.
 
     :param prefix: The prefix to lookup.
-    :returns: The Wikidata prefix (i.e., property identifier) corresponding to the prefix, if mappable.
+
+    :returns: The Wikidata prefix (i.e., property identifier) corresponding to the
+        prefix, if mappable.
 
     >>> get_wikidata_prefix("chebi")
     'P683'
@@ -348,6 +364,7 @@ def get_bioportal_prefix(prefix: str) -> str | None:
     """Get the BioPortal prefix if available.
 
     :param prefix: The prefix to lookup.
+
     :returns: The BioPortal prefix corresponding to the prefix, if mappable.
 
     >>> get_bioportal_prefix("chebi")
@@ -382,6 +399,7 @@ def get_obofoundry_uri_prefix(prefix: str) -> str | None:
     """Get the URI prefix for an OBO Foundry entry.
 
     :param prefix: The prefix to lookup.
+
     :returns: The OBO PURL URI prefix corresponding to the prefix, if mappable.
 
     >>> import bioregistry
@@ -409,6 +427,7 @@ def get_fairsharing_prefix(prefix: str) -> str | None:
     """Get the FAIRSharing prefix if available.
 
     :param prefix: The prefix to lookup.
+
     :returns: The FAIRSharing prefix corresponding to the prefix, if mappable.
 
     >>> get_fairsharing_prefix("genbank")
@@ -420,25 +439,33 @@ def get_fairsharing_prefix(prefix: str) -> str | None:
 def get_banana(prefix: str) -> str | None:
     """Get the optional redundant prefix to go before an identifier.
 
-    A "banana" is an embedded prefix that isn't actually part of the identifier.
-    Usually this corresponds to the prefix itself, with some specific stylization
-    such as in the case of FBbt. The banana does NOT include a colon ":" at the end
+    A "banana" is an embedded prefix that isn't actually part of the identifier. Usually
+    this corresponds to the prefix itself, with some specific stylization such as in the
+    case of FBbt. The banana does NOT include a colon ":" at the end
 
     :param prefix: The name of the prefix (possibly unnormalized)
-    :return: The banana, if the prefix is valid and has an associated banana.
+
+    :returns: The banana, if the prefix is valid and has an associated banana.
 
     Explicitly annotated banana
-    >>> assert "GO_REF" == get_banana("go.ref")
+
+    >>> get_banana("go.ref")
+    'GO_REF'
 
     Banana imported through OBO Foundry
-    >>> assert "GO" == get_banana("go")
-    >>> assert "VariO" == get_banana("vario")
+
+    >>> get_banana("go")
+    'GO'
+    >>> get_banana("vario")
+    'VariO'
 
     Banana inferred for OBO Foundry ontology
+
     >>> get_banana("chebi")
     'CHEBI'
 
     No banana, no namespace in LUI
+
     >>> assert get_banana("pdb") is None
     """
     entry = get_resource(prefix)
@@ -451,6 +478,7 @@ def get_default_format(prefix: str) -> str | None:
     """Get the default, first-party URI prefix.
 
     :param prefix: The prefix to lookup.
+
     :returns: The first-party URI prefix string, if available.
 
     >>> import bioregistry
@@ -471,6 +499,7 @@ def get_miriam_uri_prefix(prefix: str, **kwargs: Any) -> str | None:
 
     :param prefix: The prefix to lookup.
     :param kwargs: Keyword arguments to pass to :meth:`Resource.get_miriam_uri_prefix`
+
     :returns: The Identifiers.org/MIRIAM URI prefix, if available.
 
     >>> import bioregistry
@@ -491,6 +520,7 @@ def get_miriam_uri_format(prefix: str, **kwargs: Any) -> str | None:
 
     :param prefix: The prefix to lookup.
     :param kwargs: Keyword arguments to pass to :meth:`Resource.get_miriam_uri_format`
+
     :returns: The Identifiers.org/MIRIAM URI format string, if available.
 
     >>> import bioregistry
@@ -510,6 +540,7 @@ def get_obofoundry_uri_format(prefix: str) -> str | None:
     """Get the OBO Foundry URI format for this entry, if possible.
 
     :param prefix: The prefix to lookup.
+
     :returns: The OBO PURL format string, if available.
 
     >>> import bioregistry
@@ -529,9 +560,12 @@ def get_ols_uri_prefix(prefix: str) -> str | None:
     """Get the URI format for an OLS entry.
 
     :param prefix: The prefix to lookup.
+
     :returns: The OLS format string, if available.
 
-    .. warning:: This doesn't have a normal form, so it only works for OBO Foundry at the moment.
+    .. warning::
+
+        This doesn't have a normal form, so it only works for OBO Foundry at the moment.
 
     >>> import bioregistry
     >>> bioregistry.get_ols_uri_prefix("go")  # standard
@@ -550,9 +584,12 @@ def get_ols_uri_format(prefix: str) -> str | None:
     """Get the URI format for an OLS entry.
 
     :param prefix: The prefix to lookup.
+
     :returns: The OLS format string, if available.
 
-    .. warning:: This doesn't have a normal form, so it only works for OBO Foundry at the moment.
+    .. warning::
+
+        This doesn't have a normal form, so it only works for OBO Foundry at the moment.
 
     >>> import bioregistry
     >>> bioregistry.get_ols_uri_format("go")  # standard
@@ -571,6 +608,7 @@ def get_biocontext_uri_format(prefix: str) -> str | None:
     """Get the URI format for a BioContext entry.
 
     :param prefix: The prefix to lookup.
+
     :returns: The BioContext URI format string, if available.
 
     >>> import bioregistry
@@ -587,6 +625,7 @@ def get_prefixcommons_uri_format(prefix: str) -> str | None:
     """Get the URI format for a Prefix Commons entry.
 
     :param prefix: The prefix to lookup.
+
     :returns: The Prefix Commons URI format string, if available.
 
     >>> import bioregistry
@@ -618,9 +657,10 @@ def is_deprecated(prefix: str) -> bool:
     """Return if the given prefix corresponds to a deprecated resource.
 
     :param prefix: The prefix to lookup
-    :returns: If the prefix has been explicitly marked as deprecated either by
-        the Bioregistry, OBO Foundry, OLS, or MIRIAM. If no marks are present,
-        assumed not to be deprecated.
+
+    :returns: If the prefix has been explicitly marked as deprecated either by the
+        Bioregistry, OBO Foundry, OLS, or MIRIAM. If no marks are present, assumed not
+        to be deprecated.
 
     >>> import bioregistry
     >>> assert bioregistry.is_deprecated("imr")  # marked by OBO
@@ -635,6 +675,7 @@ def get_contact(prefix: str) -> Attributable | None:
     """Return the contact, if available.
 
     :param prefix: The prefix to lookup
+
     :returns: The resource's contact, if it is available.
     """
     entry = get_resource(prefix)
@@ -647,6 +688,7 @@ def get_contact_email(prefix: str) -> str | None:
     """Return the contact email, if available.
 
     :param prefix: The prefix to lookup
+
     :returns: The resource's contact email address, if it is available.
 
     >>> import bioregistry
@@ -666,6 +708,7 @@ def get_contact_github(prefix: str) -> str | None:
     """Return the contact GitHub, if available.
 
     :param prefix: The prefix to lookup
+
     :returns: The resource's contact GitHub handle, if it is available.
     """
     entry = get_resource(prefix)
@@ -678,6 +721,7 @@ def get_contact_orcid(prefix: str) -> str | None:
     """Return the contact ORCiD, if available.
 
     :param prefix: The prefix to lookup
+
     :returns: The resource's contact ORCiD, if it is available.
     """
     entry = get_resource(prefix)
@@ -690,6 +734,7 @@ def get_contact_name(prefix: str) -> str | None:
     """Return the contact name, if available.
 
     :param prefix: The prefix to lookup
+
     :returns: The resource's contact name, if it is available.
 
     >>> import bioregistry
@@ -750,12 +795,29 @@ def get_rdf_download(prefix: str) -> str | None:
     return entry.get_download_rdf()
 
 
+def get_skos_download(prefix: str) -> str | None:
+    """Get the download link for the SKOS RDF file."""
+    entry = get_resource(prefix)
+    if entry is None:
+        return None
+    return entry.get_download_skos()
+
+
+def get_jskos_download(prefix: str) -> str | None:
+    """Get the download link for the JSKOS JSON file."""
+    entry = get_resource(prefix)
+    if entry is None:
+        return None
+    return entry.get_download_jskos()
+
+
 def get_provides_for(prefix: str) -> str | None:
     """Get the resource that the given prefix provides for, or return none if not a provider.
 
     :param prefix: The prefix to look up
-    :returns: The prefix of the resource that the given prefix provides for, if it's a provider.
-        This is the inverse of :func:`get_provided_by`.
+
+    :returns: The prefix of the resource that the given prefix provides for, if it's a
+        provider. This is the inverse of :func:`get_provided_by`.
 
     >>> assert get_provides_for("pdb") is None
     >>> assert "pdb" == get_provides_for("validatordb")
@@ -767,8 +829,9 @@ def get_provided_by(prefix: str) -> list[str] | None:
     """Get the resources that provide for the given prefix, or return none if the prefix can't be looked up.
 
     :param prefix: The prefix to look up
-    :returns: The prefixes of the resources that provide for the given prefix. This
-        is the inverse of :func:`get_provides_for`.
+
+    :returns: The prefixes of the resources that provide for the given prefix. This is
+        the inverse of :func:`get_provides_for`.
 
     >>> get_provides_for("validatordb")
     'pdb'
@@ -780,8 +843,9 @@ def get_part_of(prefix: str) -> str | None:
     """Get the parent resource.
 
     :param prefix: The prefix to look up
-    :returns: The prefixes of the parent resource for this prefix, if one is annotated. This
-        is the inverse of :func:`get_has_parts`.
+
+    :returns: The prefixes of the parent resource for this prefix, if one is annotated.
+        This is the inverse of :func:`get_has_parts`.
 
     >>> assert "chembl" in get_part_of("chembl.compound")
     """
@@ -792,8 +856,9 @@ def get_has_parts(prefix: str) -> list[str] | None:
     """Get children resources.
 
     :param prefix: The prefix to look up
-    :returns: The prefixes of resource for which this prefix is the parent. This
-        is the inverse of :func:`get_has_parts`.
+
+    :returns: The prefixes of resource for which this prefix is the parent. This is the
+        inverse of :func:`get_has_parts`.
 
     >>> assert "chembl.compound" in get_has_parts("chembl")
     """
@@ -804,6 +869,7 @@ def get_license(prefix: str) -> str | None:
     """Get the license for the resource.
 
     :param prefix: The prefix to look up
+
     :returns: The license of the resource (normalized) if available
     """
     entry = get_resource(prefix)
@@ -816,7 +882,9 @@ def is_proprietary(prefix: str) -> bool | None:
     """Get if the prefix is proprietary.
 
     :param prefix: The prefix to look up
-    :returns: If the prefix corresponds to a proprietary resource. Assume false if not annotated explicitly
+
+    :returns: If the prefix corresponds to a proprietary resource. Assume false if not
+        annotated explicitly
 
     >>> assert is_proprietary("eurofir")
     >>> assert not is_proprietary("chebi")
@@ -833,6 +901,7 @@ def is_obo_foundry(prefix: str) -> bool | None:
     """Get if the prefix has an OBO Foundry link.
 
     :param prefix: The prefix to look up
+
     :returns: If the prefix corresponds to an OBO Foundry resource
 
     >>> assert is_obo_foundry("chebi")
@@ -862,9 +931,10 @@ def get_curie_pattern(prefix: str, *, use_preferred: bool = False) -> str | None
     """Get the CURIE pattern for this resource.
 
     :param prefix: The prefix to look up
-    :param use_preferred: Should the preferred prefix be used instead
-        of the Bioregistry prefix (if it exists)?
-    :return: The regular expression pattern to match CURIEs against
+    :param use_preferred: Should the preferred prefix be used instead of the Bioregistry
+        prefix (if it exists)?
+
+    :returns: The regular expression pattern to match CURIEs against
     """
     return manager.get_curie_pattern(prefix, use_preferred=use_preferred)
 
@@ -887,17 +957,15 @@ def is_novel(prefix: str) -> bool | None:
 def get_parts_collections() -> Mapping[str, list[str]]:
     """Group resources' prefixes based on their ``part_of`` entries.
 
-    :returns:
-        A dictionary with keys that appear as the values of ``Resource.part_of``
-        and whose values are lists of prefixes for resources that have the key
-        as a value in its ``part_of`` field.
+    :returns: A dictionary with keys that appear as the values of ``Resource.part_of``
+        and whose values are lists of prefixes for resources that have the key as a
+        value in its ``part_of`` field.
 
     .. warning::
 
-        Many of the keys in this dictionary are valid Bioregistry prefixes,
-        but this is not necessary. For example, ``ctd`` is one key that
-        appears that explicitly has no prefix, since it corresponds to a
-        resource and not a vocabulary.
+        Many of the keys in this dictionary are valid Bioregistry prefixes, but this is
+        not necessary. For example, ``ctd`` is one key that appears that explicitly has
+        no prefix, since it corresponds to a resource and not a vocabulary.
     """
     return manager.get_parts_collections()
 
@@ -905,9 +973,10 @@ def get_parts_collections() -> Mapping[str, list[str]]:
 def get_obo_context_prefix_map(include_synonyms: bool = False) -> Mapping[str, str]:
     """Get the OBO Foundry prefix map.
 
-    :param include_synonyms: Should synonyms of each prefix also be included as additional prefixes, but with
-        the same URL prefix?
-    :return: A mapping from prefixes to prefix URLs.
+    :param include_synonyms: Should synonyms of each prefix also be included as
+        additional prefixes, but with the same URL prefix?
+
+    :returns: A mapping from prefixes to prefix URLs.
     """
     return manager.get_context_artifacts("obo", include_synonyms=include_synonyms)[0]
 
